==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/representations/TypeConstants.h <==
// public class soot.jimple.toolkits.pointer.representations.TypeConstants

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 600114198fa22c15 soot_jimple_toolkits_pointer_representations_TypeConstants

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_representations_TypeConstants_H_
#define _JC_soot_jimple_toolkits_pointer_representations_TypeConstants_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$sub_refs	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$refs	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$nonrefs	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$object	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vmethods	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vtable	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vtype	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$object *, struct _jc_soot_Singletons__24Global$object *);

// Static methods
extern struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$object *_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$method$v$afc82ee011c5ccc6(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vmethods {
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vmethods	soot_jimple_toolkits_pointer_representations_TypeConstants;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$sub_refs {
	struct _jc_soot_Type$object	*OBJECTCLASS;
	struct _jc_soot_Type$object	*STRINGCLASS;
	struct _jc_soot_Type$object	*CLASSLOADERCLASS;
	struct _jc_soot_Type$object	*PROCESSCLASS;
	struct _jc_soot_Type$object	*THREADCLASS;
	struct _jc_soot_Type$object	*CLASSCLASS;
	struct _jc_soot_Type$object	*LEASTCLASS;
	struct _jc_soot_Type$object	*FIELDCLASS;
	struct _jc_soot_Type$object	*METHODCLASS;
	struct _jc_soot_Type$object	*CONSTRUCTORCLASS;
	struct _jc_soot_Type$object	*FILESYSTEMCLASS;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$refs {
    _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$sub_refs	soot_jimple_toolkits_pointer_representations_TypeConstants;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$sub_nonrefs	soot_jimple_toolkits_pointer_representations_TypeConstants;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$object {
	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vtype _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_representations_TypeConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_representations_TypeConstants_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/representations/TypeConstants.h <==
// public class soot.jimple.toolkits.pointer.representations.TypeConstants

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 600114198fa22c15 soot_jimple_toolkits_pointer_representations_TypeConstants

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_representations_TypeConstants_H_
#define _JC_soot_jimple_toolkits_pointer_representations_TypeConstants_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$sub_refs	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$refs	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$nonrefs	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$object	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vmethods	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vtable	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vtype	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$object *_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$method$v$afc82ee011c5ccc6(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vmethods {
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vmethods	soot_jimple_toolkits_pointer_representations_TypeConstants;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$sub_refs {
	struct _jc_soot_Type$object	*OBJECTCLASS;
	struct _jc_soot_Type$object	*STRINGCLASS;
	struct _jc_soot_Type$object	*CLASSLOADERCLASS;
	struct _jc_soot_Type$object	*PROCESSCLASS;
	struct _jc_soot_Type$object	*THREADCLASS;
	struct _jc_soot_Type$object	*CLASSCLASS;
	struct _jc_soot_Type$object	*LEASTCLASS;
	struct _jc_soot_Type$object	*FIELDCLASS;
	struct _jc_soot_Type$object	*METHODCLASS;
	struct _jc_soot_Type$object	*CONSTRUCTORCLASS;
	struct _jc_soot_Type$object	*FILESYSTEMCLASS;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$refs {
    _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$sub_refs	soot_jimple_toolkits_pointer_representations_TypeConstants;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$sub_nonrefs	soot_jimple_toolkits_pointer_representations_TypeConstants;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$object {
	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_representations_TypeConstants$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$vtype _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_representations_TypeConstants, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_representations_TypeConstants$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_representations_TypeConstants_H_ */
